cumulusci.tasks.release\_notes.tests package
============================================

Submodules
----------

cumulusci.tasks.release\_notes.tests.test\_generator module
-----------------------------------------------------------

.. automodule:: cumulusci.tasks.release_notes.tests.test_generator
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.release\_notes.tests.test\_parser module
--------------------------------------------------------

.. automodule:: cumulusci.tasks.release_notes.tests.test_parser
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.release\_notes.tests.test\_provider module
----------------------------------------------------------

.. automodule:: cumulusci.tasks.release_notes.tests.test_provider
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.release\_notes.tests.test\_task module
------------------------------------------------------

.. automodule:: cumulusci.tasks.release_notes.tests.test_task
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.release\_notes.tests.utils module
-------------------------------------------------

.. automodule:: cumulusci.tasks.release_notes.tests.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks.release_notes.tests
    :members:
    :undoc-members:
    :show-inheritance:
